@@ -31,10 +31,9 @@ fn random_numbers(count: usize) -> Vec<u32> {
 fn overview_bench(c: &mut Criterion) {
     c.bench_function("zerovec_serde/overview", |b| {
         // Same as "zerovec_serde/deserialize_sum/u32/zerovec"
-        let buffer = bincode::serialize(
-            &ZeroVec::<u32>::try_from_bytes(black_box(&TEST_BUFFER_LE)).unwrap(),
-        )
-        .unwrap();
+        let buffer =
+            bincode::serialize(&ZeroVec::<u32>::try_from_bytes(black_box(TEST_BUFFER_LE)).unwrap())
+                .unwrap();
         b.iter(|| {
             bincode::deserialize::<ZeroVec<u32>>(&buffer)
                 .unwrap()
@@ -68,14 +67,13 @@ fn u32_benches(c: &mut Criterion) {
     });
 
     c.bench_function("zerovec_serde/serialize/u32/zerovec", |b| {
-        b.iter(|| bincode::serialize(&ZeroVec::from_aligned(black_box(TEST_SLICE))));
+        b.iter(|| bincode::serialize(&ZeroVec::from_slice(black_box(TEST_SLICE))));
     });
 
     c.bench_function("zerovec_serde/deserialize_sum/u32/zerovec", |b| {
-        let buffer = bincode::serialize(
-            &ZeroVec::<u32>::try_from_bytes(black_box(&TEST_BUFFER_LE)).unwrap(),
-        )
-        .unwrap();
+        let buffer =
+            bincode::serialize(&ZeroVec::<u32>::try_from_bytes(black_box(TEST_BUFFER_LE)).unwrap())
+                .unwrap();
         b.iter(|| {
             bincode::deserialize::<ZeroVec<u32>>(&buffer)
                 .unwrap()
@@ -101,11 +99,11 @@ fn char_benches(c: &mut Criterion) {
     });
 
     c.bench_function("zerovec_serde/serialize/char/zerovec", |b| {
-        b.iter(|| bincode::serialize(&ZeroVec::from_aligned(black_box(ORIGINAL_CHARS))));
+        b.iter(|| bincode::serialize(&ZeroVec::from_slice(black_box(ORIGINAL_CHARS))));
     });
 
     c.bench_function("zerovec_serde/deserialize/char/zerovec", |b| {
-        let buffer = bincode::serialize(&ZeroVec::from_aligned(black_box(ORIGINAL_CHARS))).unwrap();
+        let buffer = bincode::serialize(&ZeroVec::from_slice(black_box(ORIGINAL_CHARS))).unwrap();
         b.iter(|| bincode::deserialize::<ZeroVec<char>>(&buffer));
     });
 }
@@ -114,7 +112,7 @@ fn char_benches(c: &mut Criterion) {
 fn stress_benches(c: &mut Criterion) {
     let number_vec = random_numbers(100);
     let bincode_vec = bincode::serialize(&number_vec).unwrap();
-    let zerovec_aligned = ZeroVec::from_aligned(number_vec.as_slice());
+    let zerovec_aligned = ZeroVec::from_slice(number_vec.as_slice());
     let bincode_zerovec = bincode::serialize(&zerovec_aligned).unwrap();
 
     // *** Deserialize vec of 100 `u32` ***
