@@ -140,7 +140,7 @@ where
     /// let bytes: &[u8] = &[0xD3, 0x00, 0x19, 0x01, 0xA5, 0x01, 0xCD, 0x01];
     /// let nums: &[u16] = &[211, 281, 421, 461];
     ///
-    /// let zerovec = ZeroVec::from_aligned(nums);
+    /// let zerovec = ZeroVec::clone_from_slice(nums);
     ///
     /// assert_eq!(bytes, zerovec.as_bytes());
     /// ```
@@ -205,9 +205,9 @@ impl<T> ZeroVec<'_, T>
 where
     T: AsULE,
 {
-    /// Creates a `ZeroVec<T>` from a `&[T]`.
+    /// Creates a `ZeroVec<T>` from a `&[T]` by allocating memory.
     ///
-    /// This function allocates memory and results in an `Owned` instance of `ZeroVec<T>`.
+    /// This function results in an `Owned` instance of `ZeroVec<T>`.
     ///
     /// # Example
     ///
@@ -218,13 +218,13 @@ where
     /// let bytes: &[u8] = &[0xD3, 0x00, 0x19, 0x01, 0xA5, 0x01, 0xCD, 0x01];
     /// let nums: &[u16] = &[211, 281, 421, 461];
     ///
-    /// let zerovec = ZeroVec::from_aligned(nums);
+    /// let zerovec = ZeroVec::clone_from_slice(nums);
     ///
     /// assert!(matches!(zerovec, ZeroVec::Owned(_)));
     /// assert_eq!(bytes, zerovec.as_bytes());
     /// ```
     #[inline]
-    pub fn from_aligned(other: &[T]) -> Self {
+    pub fn clone_from_slice(other: &[T]) -> Self {
         Self::Owned(other.iter().map(T::as_unaligned).collect())
     }
 
@@ -236,7 +236,7 @@ where
     /// use zerovec::ZeroVec;
     ///
     /// let nums: &[u16] = &[211, 281, 421, 461];
-    /// let vec: Vec<u16> = ZeroVec::from_aligned(nums).to_vec();
+    /// let vec: Vec<u16> = ZeroVec::clone_from_slice(nums).to_vec();
     ///
     /// assert_eq!(nums, vec.as_slice());
     /// ```
@@ -246,6 +246,59 @@ where
     }
 }
 
+impl<'a, T> ZeroVec<'a, T>
+where
+    T: AsULE + SliceAsULE,
+{
+    /// Attempts to create a `ZeroVec<'a, T>` from a `&'a [T]` by borrowing the argument.
+    ///
+    /// If this is not possible, such as on a big-endian platform, `None` is returned.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// use zerovec::ZeroVec;
+    ///
+    /// // The little-endian bytes correspond to the numbers on the following line.
+    /// let bytes: &[u8] = &[0xD3, 0x00, 0x19, 0x01, 0xA5, 0x01, 0xCD, 0x01];
+    /// let nums: &[u16] = &[211, 281, 421, 461];
+    ///
+    /// if let Some(zerovec) = ZeroVec::try_from_slice(nums) {
+    ///     assert!(matches!(zerovec, ZeroVec::Borrowed(_)));
+    ///     assert_eq!(bytes, zerovec.as_bytes());
+    /// }
+    /// ```
+    #[inline]
+    pub fn try_from_slice(slice: &'a [T]) -> Option<Self> {
+        T::slice_as_unaligned(slice).map(|ule_slice| Self::Borrowed(ule_slice))
+    }
+
+    /// Creates a `ZeroVec<'a, T>` from a `&'a [T]`, either by borrowing the argument or by
+    /// allocating a new vector.
+    ///
+    /// This is a cheap operation on little-endian platforms, falling back to a more expensive
+    /// operation on big-endian platforms.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// use zerovec::ZeroVec;
+    ///
+    /// // The little-endian bytes correspond to the numbers on the following line.
+    /// let bytes: &[u8] = &[0xD3, 0x00, 0x19, 0x01, 0xA5, 0x01, 0xCD, 0x01];
+    /// let nums: &[u16] = &[211, 281, 421, 461];
+    ///
+    /// let zerovec = ZeroVec::from_slice(nums);
+    ///
+    /// // Note: zerovec could be either borrowed or owned.
+    /// assert_eq!(bytes, zerovec.as_bytes());
+    /// ```
+    #[inline]
+    pub fn from_slice(slice: &'a [T]) -> Self {
+        Self::try_from_slice(slice).unwrap_or_else(|| Self::clone_from_slice(slice))
+    }
+}
+
 impl<T> ZeroVec<'_, T>
 where
     T: AsULE + Copy + ?Sized,
@@ -427,13 +480,13 @@ mod tests {
     #[test]
     fn test_get() {
         {
-            let zerovec = ZeroVec::from_aligned(TEST_SLICE);
+            let zerovec = ZeroVec::from_slice(TEST_SLICE);
             assert_eq!(zerovec.get(0), Some(TEST_SLICE[0]));
             assert_eq!(zerovec.get(1), Some(TEST_SLICE[1]));
             assert_eq!(zerovec.get(2), Some(TEST_SLICE[2]));
         }
         {
-            let zerovec = ZeroVec::<u32>::try_from_bytes(&TEST_BUFFER_LE).unwrap();
+            let zerovec = ZeroVec::<u32>::try_from_bytes(TEST_BUFFER_LE).unwrap();
             assert_eq!(zerovec.get(0), Some(TEST_SLICE[0]));
             assert_eq!(zerovec.get(1), Some(TEST_SLICE[1]));
             assert_eq!(zerovec.get(2), Some(TEST_SLICE[2]));
@@ -443,12 +496,12 @@ mod tests {
     #[test]
     fn test_binary_search() {
         {
-            let zerovec = ZeroVec::from_aligned(TEST_SLICE);
+            let zerovec = ZeroVec::from_slice(TEST_SLICE);
             assert_eq!(Ok(3), zerovec.binary_search(&0x0e0d0c));
             assert_eq!(Err(3), zerovec.binary_search(&0x0c0d0c));
         }
         {
-            let zerovec = ZeroVec::<u32>::try_from_bytes(&TEST_BUFFER_LE).unwrap();
+            let zerovec = ZeroVec::<u32>::try_from_bytes(TEST_BUFFER_LE).unwrap();
             assert_eq!(Ok(3), zerovec.binary_search(&0x0e0d0c));
             assert_eq!(Err(3), zerovec.binary_search(&0x0c0d0c));
         }
@@ -458,7 +511,7 @@ mod tests {
     fn test_odd_alignment() {
         assert_eq!(
             Some(0x020100),
-            ZeroVec::<u32>::try_from_bytes(&TEST_BUFFER_LE)
+            ZeroVec::<u32>::try_from_bytes(TEST_BUFFER_LE)
                 .unwrap()
                 .get(0)
         );
@@ -506,7 +559,7 @@ mod tests {
         );
         assert_eq!(
             Some(0x4e4d4c),
-            ZeroVec::<u32>::try_from_bytes(&TEST_BUFFER_LE)
+            ZeroVec::<u32>::try_from_bytes(TEST_BUFFER_LE)
                 .unwrap()
                 .get(19)
         );
@@ -518,7 +571,7 @@ mod tests {
         );
         assert_eq!(
             None,
-            ZeroVec::<u32>::try_from_bytes(&TEST_BUFFER_LE)
+            ZeroVec::<u32>::try_from_bytes(TEST_BUFFER_LE)
                 .unwrap()
                 .get(20)
         );
