@@ -103,16 +103,13 @@ mod test {
 
     #[test]
     fn test_serde_json() {
-        let zerovec_orig = ZeroVec::from_aligned(TEST_SLICE);
+        let zerovec_orig = ZeroVec::from_slice(TEST_SLICE);
         let json_str = serde_json::to_string(&zerovec_orig).expect("serialize");
         assert_eq!(JSON_STR, json_str);
         // ZeroVec should deserialize from JSON to either Vec or ZeroVec
         let vec_new: Vec<u32> =
             serde_json::from_str(&json_str).expect("deserialize from buffer to Vec");
-        assert_eq!(
-            zerovec_orig,
-            ZeroVec::<u32>::from_aligned(vec_new.as_slice())
-        );
+        assert_eq!(zerovec_orig, ZeroVec::<u32>::from_slice(vec_new.as_slice()));
         let zerovec_new: ZeroVec<u32> =
             serde_json::from_str(&json_str).expect("deserialize from buffer to ZeroVec");
         assert_eq!(zerovec_orig, zerovec_new);
@@ -121,7 +118,7 @@ mod test {
 
     #[test]
     fn test_serde_bincode() {
-        let zerovec_orig = ZeroVec::from_aligned(TEST_SLICE);
+        let zerovec_orig = ZeroVec::from_slice(TEST_SLICE);
         let bincode_buf = bincode::serialize(&zerovec_orig).expect("serialize");
         assert_eq!(BINCODE_BUF, bincode_buf);
         // ZeroVec should deserialize from Bincode to ZeroVec but not Vec
@@ -135,7 +132,7 @@ mod test {
     #[test]
     fn test_chars_valid() {
         // 1-byte, 2-byte, 3-byte, and 4-byte character in UTF-8 (not as relevant in UTF-32)
-        let zerovec_orig = ZeroVec::from_aligned(&['w', 'ω', '文', '𑄃']);
+        let zerovec_orig = ZeroVec::from_slice(&['w', 'ω', '文', '𑄃']);
         let bincode_buf = bincode::serialize(&zerovec_orig).expect("serialize");
         let zerovec_new: ZeroVec<char> =
             bincode::deserialize(&bincode_buf).expect("deserialize from buffer to ZeroVec");
@@ -146,7 +143,7 @@ mod test {
     #[test]
     fn test_chars_invalid() {
         // 119 and 120 are valid, but not 0xD800 (high surrogate)
-        let zerovec_orig: ZeroVec<u32> = ZeroVec::from_aligned(&[119, 0xD800, 120]);
+        let zerovec_orig: ZeroVec<u32> = ZeroVec::from_slice(&[119, 0xD800, 120]);
         let bincode_buf = bincode::serialize(&zerovec_orig).expect("serialize");
         let zerovec_result = bincode::deserialize::<ZeroVec<char>>(&bincode_buf);
         assert!(matches!(zerovec_result, Err(_)));
